==> vue-plugin-0.4.1.tgz: package/README.md <==
# @friendly-tnsvue/vue-plugin
The Plugin that really simplifies your NSVue application

## 😎 How to Install
```sh
# With NPM
npm install @friendly-tnsvue/vue-plugin

# Or Yarn:
yarn add @friendly-tnsvue/vue-plugin
```

## 😅 Get's started
Add this into your entry-point
```js
import FriendlyTnsVue from "@friendly-tnsvue/vue-plugin";
// INFO: plese keep this above all others `Vue.use`
Vue.use(FriendlyTnsVue); 
```
## Components
- div
  - props
    - lStyle

      **Type:** `String, Object`

      **Examples:**
      ```html
      <!-- typeof lStyle === string -->
      <div lStyle="display: flex; align-items: center">
      </div>
      ```
      ```html
      <!-- typeof lStyle === object -->
      <div :lStyle="{ display: 'flex', alignItems: 'center' }">
      </div>
      <!-- NOTE: don't forget to use ":lStyle" (or "v-bind:lStyle") -->
      ```

      **display:**
      ```js
      const layoutTypes = {
        absolute: 'AbsoluteLayout',
        dock: 'DockLayout',
        flex: 'FlexboxLayout',
        grid: 'GridLayout',
        stack: 'StackLayout',
        wrap: 'WrapLayout',
      };
      layoutTypes.block = layoutTypes.stack;
      layoutTypes.default = layoutTypes.stack;
      ```

      With the exception of the `display` property, the other properties correspond to HTML attributes, interpreted by NativeScript.

      Please visit the layout section of [documentation](https://nativescript-vue.org/en/docs/introduction/)

- span
  ```html
  <span>olá</span>
  <!-- equals to -->
  <Label text="olá" />
  ```
  **Examples**:
  ```html
  <span>Qual é o doce mais doce que o doce de batata doce?</span>
  ```
  
- p
  ```html
  <p>lancha</p>
  <!-- equals to -->
  <div>
    <span>lancha</span>
  </div>
  ```
  **Examples**:
  ```html
  <p>plante árvores</p>
  ```

## 🤝 Contribute
Please send pull-requests, share with friends, improve the source-code...

## 📝 License
Licensed under the [MIT License](LICENSE.md).

Created by [Gabriel Rodrigues](https://github.com/gabrodbr)

==> vue-plugin-0.5.2.tgz: package/README.md <==
# friendly-tnsvue/vue-plugin
> The Plugin that really simplifies your NSVue application

## Install
```sh
# With NPM
npm install @friendly-tnsvue/vue-plugin

# Or Yarn:
yarn add @friendly-tnsvue/vue-plugin
```

## Load
Add this into your entry-point
```js
import FriendlyTnsVue from "@friendly-tnsvue/vue-plugin";

Vue.use(FriendlyTnsVue); 
```
## Components
- div
  - props
    - lStyle

      **Type:** `String, Object`

      **Examples:**
      ```html
      <!-- typeof lStyle === string -->
      <div lStyle="display: flex; align-items: center">
      </div>
      ```
      ```html
      <!-- typeof lStyle === object -->
      <div :lStyle="{ display: 'flex', alignItems: 'center' }">
      </div>
      <!-- NOTE: don't forget to use ":lStyle" (or "v-bind:lStyle") -->
      ```

      **display:**
      ```js
      const layoutTypes = {
        absolute: 'AbsoluteLayout',
        dock: 'DockLayout',
        flex: 'FlexboxLayout',
        grid: 'GridLayout',
        stack: 'StackLayout',
        wrap: 'WrapLayout',
      };
      layoutTypes.block = layoutTypes.stack;
      layoutTypes.default = layoutTypes.stack;
      ```

      With the exception of the `display` property, the other properties correspond to HTML attributes, interpreted by NativeScript.

      Please visit the layout section of [documentation](https://nativescript-vue.org/en/docs/introduction/)

- span
  ```html
  <span>olá</span>
  <!-- equals to -->
  <Label text="olá" />
  ```
  **Examples**:
  ```html
  <span>Qual é o doce mais doce que o doce de batata doce?</span>
  ```
  
- p
  ```html
  <p>lancha</p>
  <!-- equals to -->
  <div>
    <span>lancha</span>
  </div>
  ```
  **Examples**:
  ```html
  <p>plante árvores</p>
  ```

## Build
```sh
yarn run build
```
will create the lib directory with the transpiled files

## 🤝 Contribute
Please send pull-requests, share with friends

## 📝 License
Licensed under the [MIT License](LICENSE).

Created by [Gabriel Rodrigues](https://github.com/guesant)
